@@ -2,7 +2,7 @@
 
 # Title:  General helper functions
 # Author: Sebastian Weinand
-# Date:   16 January 2024
+# Date:   18 May 2024
 
 # set base region:
 set.base <- function(r, base, null.ok, qbase=FALSE, settings=list()){
@@ -119,9 +119,9 @@ arrange <- function(p, r, n, q=NULL, w=NULL, base, settings=list()){
 
     # average duplicated prices and weights, sum duplicated quantities:
     if(is.null(q)){
-      dt <- dt[, list("p"=stats::weighted.mean(x=p, w=z), "z"=mean(z)), by=c("r","n")]
+      dt <- dt[, list("p"=stats::weighted.mean(x=p, w=ifelse(is.na(z), 0, z), na.rm=TRUE), "z"=mean(z, na.rm=TRUE)), by=c("r","n")]
     }else{
-      dt <- dt[, list("p"=stats::weighted.mean(x=p, w=z), "z"=sum(z)), by=c("r","n")]
+      dt <- dt[, list("p"=stats::weighted.mean(x=p, w=ifelse(is.na(z), 0, z), na.rm=TRUE), "z"=sum(z, na.rm=TRUE)), by=c("r","n")]
     }
 
     # print warning:
@@ -143,7 +143,7 @@ arrange <- function(p, r, n, q=NULL, w=NULL, base, settings=list()){
       dt[, "q" := NA_real_]
       if(settings$norm.weights){
         # normalize given weights:
-        dt[, "w" := z/sum(z), by="r"]
+        dt[, "w" := z/sum(z, na.rm=TRUE), by="r"]
       }else{
         # else go with provided input:
         dt[, "w" := z]
@@ -162,4 +162,45 @@ arrange <- function(p, r, n, q=NULL, w=NULL, base, settings=list()){
 
 }
 
+# plot price ratios and price levels:
+plot.pricelevels <- function(data, P=numeric()){
+
+  # @Args:
+  # data    a data.frame with columns region and ratio
+  # P       a vector or matrix with price levels
+
+  # create empty boxplot:
+  graphics::boxplot(ratio~region, data=data,
+                    border=NA,
+                    axes=FALSE,
+                    xlab="Region",
+                    ylab="Price levels and ratios",
+                    main="Price ratios and price levels of the regions")
+
+  # add horizontal lines:
+  y.ticks <- graphics::par("yaxp")
+  graphics::abline(h=seq(from=y.ticks[1], to=y.ticks[2], length=y.ticks[3]+1),
+                   col="lightgrey", lty=2)
+
+  # add horizontal line at equality:
+  graphics::abline(h=1, col="lightgrey", lty=2)
+
+  # add vertical lines:
+  x.ticks <- graphics::par("xaxp")
+  graphics::abline(v=seq(from=x.ticks[1], to=x.ticks[2], length=x.ticks[3]+1),
+                   col="lightgrey", lty=2)
+
+  # add boxplot:
+  graphics::boxplot(ratio~region, data=data, add=TRUE)
+
+  # add price indices:
+  if(is.matrix(P)){
+    if(nrow(P)>1) mycols <- 1:nrow(P) else mycols <- "red"
+    graphics::matpoints(t(P), pch=20, cex=1.5, col=mycols)
+  }else{
+    graphics::matpoints(P, pch=20, cex=1.5, col="red")
+  }
+
+}
+
 # END
