@@ -70,7 +70,7 @@ expect_equal(
 cpd.q <- exp(c(0, lm(log(price) ~ product+region-1, data=dt, weights=quantity)$coef[5:6]))
 cpd.q <- setNames(cpd.q, 1:3)
 expect_equal(
-  dt[, cpd(p=price, r=region, n=product, w=quantity, base="1")],
+  dt[, cpd(p=price, r=region, n=product, w=quantity, base="1", settings=list("norm.weights"=FALSE))],
   cpd.q
 )
 
@@ -101,7 +101,7 @@ ub <- list("lnP"=setNames(rep(Inf, 2), 2:3), "pi"=setNames(rep(Inf, 4), 1:4), "d
 lb <- list("lnP"=setNames(rep(-Inf, 2), 2:3), "pi"=setNames(rep(-Inf, 4), 1:4), "delta"=setNames(rep(1, 3), 2:4))
 expect_equal(
   dt[, nlcpd(p=price, r=region, n=product, w=quantity, base="1", simplify=TRUE,
-               upper=unlist(ub), lower=unlist(lb))],
+               upper=unlist(ub), lower=unlist(lb), settings=list("norm.weights"=FALSE))],
   cpd.q,
   tolerance=1e-5
 )
